# HyperJet
Automatic differentiation with dual numbers

[![Build Status](https://github.com/oberbichler/HyperJet/workflows/Python%20package/badge.svg?branch=master)](https://github.com/oberbichler/HyperJet/actions) [![PyPI](https://img.shields.io/pypi/v/hyperjet)](https://pypi.org/project/hyperjet)

## Installation

```
pip install hyperjet
```

## Documentation

https://oberbichler.github.io/HyperJet/

## Try

[![Binder](https://img.shields.io/badge/Launch-Binder-blue?style=for-the-badge&logo=python)](https://mybinder.org/v2/gh/oberbichler/HyperJet-Binder/master?urlpath=%2Fnteract%2Fedit%2Fexample.ipynb)

## Reference

If you use HyperJet, please refer to the official GitHub repository:

```
@misc{HyperJet,
  author = "Thomas Oberbichler",
  title = "HyperJet",
  howpublished = "\url{http://github.com/oberbichler/HyperJet}",
}
```
